AuditLogChange class

A change to an object's field in an AuditLogEntry.

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → String
The name of the affected field.
final
newValue → dynamic
The new, unparsed value of the field.
final
oldValue → dynamic
The old, unparsed value of the field.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

defaultToString() → String
Same as toString, but only called when dart:mirrors is not available.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited