ClientStatus class

The status of a client on multiple platforms.

Properties

desktop → UserStatus?
The client's status on a desktop session.
final
hashCode → int
The hash code for this object.
no setterinherited
mobile → UserStatus?
The client's status on a mobile session.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
web → UserStatus?
The client's status on a web session, or a bot client's status.
final

Methods

defaultToString() → String
Same as toString, but only called when dart:mirrors is not available.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited