DefaultValue<T extends SnowflakeEntity<T>> class

Inheritance

Constructors

DefaultValue({required Snowflake id, required String type})

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ Snowflake
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
getter/setter pair

Methods

build() → Map<String, Object?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

channel({required Snowflake id}) → DefaultValue<Channel>
role({required Snowflake id}) → DefaultValue<Role>
user({required Snowflake id}) → DefaultValue<User>