DirectoryChannel class

A directory channel.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → Snowflake
The id of this entity.
finalinherited
json → Map<String, Object?>
finalinherited
manager → ChannelManager
The manager for this entity.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ChannelType
The type of this channel.
no setteroverride

Methods

defaultToString() → String
Same as toString, but only called when dart:mirrors is not available.
inherited
delete({String? auditLogReason}) → Future<void>
Delete this channel.
inherited
fetch() → Future<Channel>
Fetch this entity from the API.
inherited
follow(Snowflake id) → Future<void>
Follow another channel's announcement messages in this channel.
inherited
get() → Future<Channel>
If this entity exists in the manager's cache, return the cached instance. Otherwise, fetch this entity and return it.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
update(UpdateBuilder<Channel> builder) → Future<Channel>
Update this channel.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited