EmojiUpdateBuilder class

Implemented types

Constructors

EmojiUpdateBuilder({String? name, Iterable<Snowflake>? roles = sentinelList})

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the emoji.
getter/setter pair
roles ↔ Iterable<Snowflake>?
The roles allowed to use this emoji.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → Map<String, Object?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited