EntitlementDeleteEvent class

Emitted when an entitlement is deleted.

Inheritance

Properties

deletedEntitlement → Entitlement?
The entitlement as it was cached before it was deleted.
final
entitlement → Entitlement
The entitlement that was deleted.
final
gateway → Gateway
The gateway that handled this event.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
opcode → Opcode
The opcode of this event.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

defaultToString() → String
Same as toString, but only called when dart:mirrors is not available.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited