GlobalSticker class

A sticker that can be sent in messages. Represents global stickers (default stickers)

Inheritance
Mixed-in types

Properties

available → bool
Whether this guild sticker can be used, may be false due to loss of Server Boosts
final
description → String?
Description of the sticker
final
formatType → StickerFormatType
Type of sticker format
final
hashCode → int
The hash code for this object.
no setterinherited
id → Snowflake
The id of this entity.
finalinherited
json → Map<String, Object?>
finalinherited
manager → GlobalStickerManager
The manager for this entity.
finalinherited
name → String
Name of the sticker
final
packId → Snowflake
For standard stickers, id of the pack the sticker is from
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sortValue → int?
The standard sticker's sort order within its pack
final
tags → String
Autocomplete/suggestion tags for the sticker (comma separated string)
final
type → StickerType
Type of sticker
final
user → PartialUser?
The user that uploaded the guild sticker
final

Methods

defaultToString() → String
Same as toString, but only called when dart:mirrors is not available.
inherited
fetch() → Future<GlobalSticker>
Fetch this entity from the API.
inherited
get() → Future<GlobalSticker>
If this entity exists in the manager's cache, return the cached instance. Otherwise, fetch this entity and return it.
inherited
getTags() → List<String>
Returns tags in list format since tags field is comma-separated string
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited