GuildChannel class abstract

A channel in a Guild.

Implemented types
Implementers

Constructors

GuildChannel()

Properties

guild → PartialGuild
The guild this channel is in.
no setter
guildId → Snowflake
The ID of the Guild this channel is in.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → Snowflake
The id of this entity.
finalinherited
isNsfw → bool
Whether this channel is marked as NSFW.
no setter
json → Map<String, Object?>
finalinherited
manager → ChannelManager
The manager for this entity.
finalinherited
name → String
The name of this channel.
no setter
parent → PartialChannel?
This channel's parent.
no setter
parentId → Snowflake?
The ID of this channel's parent.
no setter
permissionOverwrites → List<PermissionOverwrite>
The permission overwrites for members and roles in this channel.
no setter
position → int
The positing on this channel in the guild's channel list.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ChannelType
The type of this channel.
no setterinherited

Methods

createInvite(InviteBuilder builder, {String? auditLogReason}) → Future<Invite>
Create an invite to this channel.
defaultToString() → String
Same as toString, but only called when dart:mirrors is not available.
inherited
delete({String? auditLogReason}) → Future<void>
Delete this channel.
inherited
deletePermissionOverwrite(Snowflake id) → Future<void>
Remove a permission overwrite from this channel.
fetch() → Future<Channel>
Fetch this entity from the API.
inherited
fetchWebhooks() → Future<List<Webhook>>
List the webhooks in this channel.
follow(Snowflake id) → Future<void>
Follow another channel's announcement messages in this channel.
inherited
get() → Future<Channel>
If this entity exists in the manager's cache, return the cached instance. Otherwise, fetch this entity and return it.
inherited
listInvites() → Future<List<InviteWithMetadata>>
List the invites in this channel.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
update(UpdateBuilder<Channel> builder) → Future<Channel>
Update this channel.
inherited
updatePermissionOverwrite(PermissionOverwriteBuilder builder) → Future<void>
Update or create a permission overwrite in this channel.

Operators

operator ==(Object other) → bool
The equality operator.
inherited