GuildMediaChannel class

A channel in a guild in which threads can be posted, similarly to a ForumChannel.

Inheritance
Implemented types

Properties

availableTags → List<ForumTag>
A list of tags available in this channel.
final
defaultAutoArchiveDuration → Duration
The default Thread.autoArchiveDuration for Threads created in this channel.
final
defaultReaction → DefaultReaction?
The default reaction for this channel.
final
defaultSortOrder → ForumSort?
The default sort order in this channel
final
defaultThreadRateLimitPerUser → Duration?
The default Thread.rateLimitPerUser for Threads created in this channel.
final
flags → ChannelFlags
Any flags applied to this channel.
final
guild → PartialGuild
The guild this channel is in.
no setteroverride
guildId → Snowflake
The ID of the Guild this channel is in.
final
hashCode → int
The hash code for this object.
no setterinherited
id → Snowflake
The id of this entity.
finalinherited
isNsfw → bool
Whether this channel is marked as NSFW.
final
json → Map<String, Object?>
finalinherited
lastPinTimestamp → DateTime?
The time at which the last message was pinned.
final
lastThreadId → Snowflake?
The ID of the last Thread created.
final
manager → ChannelManager
The manager for this entity.
finalinherited
name → String
The name of this channel.
final
parent → PartialChannel?
This channel's parent.
no setteroverride
parentId → Snowflake?
The ID of this channel's parent.
final
permissionOverwrites → List<PermissionOverwrite>
The permission overwrites for members and roles in this channel.
final
position → int
The positing on this channel in the guild's channel list.
final
rateLimitPerUser → Duration?
The rate limit duration of this channel per user.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topic → String?
The topic of this channel.
final
type → ChannelType
The type of this channel.
no setteroverride

Methods

createForumThread(ForumThreadBuilder builder) → Future<Thread>
Create a thread in this thread aggregate channel.
override
createInvite(InviteBuilder builder, {String? auditLogReason}) → Future<Invite>
Create an invite to this channel.
override
createThread(ThreadBuilder builder) → Future<Thread>
Create a Thread in this channel.
override
createThreadFromMessage(Snowflake messageId, ThreadFromMessageBuilder builder) → Future<Thread>
Create a Thread from a Message in this channel.
override
defaultToString() → String
Same as toString, but only called when dart:mirrors is not available.
inherited
delete({String? auditLogReason}) → Future<void>
Delete this channel.
inherited
deletePermissionOverwrite(Snowflake id) → Future<void>
Remove a permission overwrite from this channel.
override
fetch() → Future<Channel>
Fetch this entity from the API.
inherited
fetchWebhooks() → Future<List<Webhook>>
List the webhooks in this channel.
override
follow(Snowflake id) → Future<void>
Follow another channel's announcement messages in this channel.
inherited
get() → Future<Channel>
If this entity exists in the manager's cache, return the cached instance. Otherwise, fetch this entity and return it.
inherited
listInvites() → Future<List<InviteWithMetadata>>
List the invites in this channel.
override
listJoinedPrivateArchivedThreads({DateTime? before, int? limit}) → Future<ThreadList>
List the private archived Threads in this channel which the current user has joined.
override
listPrivateArchivedThreads({DateTime? before, int? limit}) → Future<ThreadList>
List the private archived Threads in this channel.
override
listPublicArchivedThreads({DateTime? before, int? limit}) → Future<ThreadList>
List the public archived Threads in this channel.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
update(UpdateBuilder<Channel> builder) → Future<Channel>
Update this channel.
inherited
updatePermissionOverwrite(PermissionOverwriteBuilder builder) → Future<void>
Update or create a permission overwrite in this channel.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited