GuildTextChannelBuilder class

Inheritance

Constructors

GuildTextChannelBuilder({required String name, int? position, List<CreateBuilder<PermissionOverwrite>>? permissionOverwrites, String? topic, Duration? rateLimitPerUser, Snowflake? parentId, bool? isNsfw, Duration? defaultAutoArchiveDuration})

Properties

defaultAutoArchiveDuration ↔ Duration?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isNsfw ↔ bool?
getter/setter pair
name ↔ String
getter/setter pairinherited
parentId ↔ Snowflake?
getter/setter pair
permissionOverwrites ↔ List<CreateBuilder<PermissionOverwrite>>?
getter/setter pairinherited
position ↔ int?
getter/setter pairinherited
rateLimitPerUser ↔ Duration?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topic ↔ String?
getter/setter pair
type ↔ ChannelType
getter/setter pairinherited

Methods

build() → Map<String, Object?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited