PartialWebhook class

A partial Webhook.

Inheritance
Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → Snowflake
The id of this entity.
finalinherited
json → Map<String, Object?>
finalinherited
manager → WebhookManager
The manager for this entity.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

defaultToString() → String
Same as toString, but only called when dart:mirrors is not available.
inherited
delete({String? token, String? auditLogReason}) → Future<void>
Delete this webhook.
override
deleteMessage(Snowflake messageId, {required String token, Snowflake? threadId}) → Future<void>
Delete a message sent by this webhook using its token.
execute(MessageBuilder builder, {required String token, bool? wait, Snowflake? threadId, String? threadName, List<Snowflake>? appliedTags, String? username, String? avatarUrl}) → Future<Message?>
Execute this webhook using its token.
fetch() → Future<Webhook>
Fetch this entity from the API.
inherited
fetchMessage(Snowflake messageId, {required String token, Snowflake? threadId}) → Future<Message>
Fetch a message sent by this webhook using its token.
get() → Future<Webhook>
If this entity exists in the manager's cache, return the cached instance. Otherwise, fetch this entity and return it.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
update(covariant WebhookUpdateBuilder builder, {String? token, String? auditLogReason}) → Future<Webhook>
Update this webhook, returning the updated webhook.
override
updateMessage(Snowflake messageId, MessageUpdateBuilder builder, {required String token, Snowflake? threadId}) → Future<Message>
Update a message sent by this webhook using its token.

Operators

operator ==(Object other) → bool
The equality operator.
inherited