RoleNotFoundException class

An exception thrown when a role is not found in a guild.

Inheritance

Constructors

RoleNotFoundException(Snowflake guildId, Snowflake roleId)
Create a new RoleNotFoundException.

Properties

guildId → Snowflake
The ID of the guild.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
The message for this exception.
finalinherited
roleId → Snowflake
The ID of the role.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited