ShardData class

Information a shard needs to run itself.

Constructors

ShardData({required int totalShards, required int id, required GatewayApiOptions apiOptions, required Uri originalConnectionUri})
Information a shard needs to run itself.
const

Properties

apiOptions → GatewayApiOptions
The API options the client is using.
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
The ID of the current shard.
final
originalConnectionUri → Uri
The original connection URI from GatewayManager.fetchGatewayBot.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalShards → int
The total number of shards in the current session.
final

Methods

defaultToString() → String
Same as toString, but only called when dart:mirrors is not available.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited