Sku class

A premium offering that can be made available to your application's users or guilds.

Properties

application → PartialApplication
The application this SKU belongs to.
no setter
applicationId → Snowflake
The ID of the application this SKU belongs to.
final
flags → SkuFlags
This SKU's flags.
final
hashCode → int
The hash code for this object.
no setterinherited
id → Snowflake
This SKU's ID.
final
manager → ApplicationManager
The Manager for this SKU.
final
name → String
The name of this SKU.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slug → String
The URL slug for this SKU.
final
type → SkuType
This SKU's type.
final

Methods

defaultToString() → String
Same as toString, but only called when dart:mirrors is not available.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited