TextInputComponent class

A text field in a modal.

Inheritance

Properties

customId → String
This component's custom ID.
final
hashCode → int
The hash code for this object.
no setterinherited
isRequired → bool?
Whether this component requires input.
final
label → String?
This component's label.
final
maxLength → int?
The maximum number of characters the user can input.
final
minLength → int?
The minimum number of characters the user must input.
final
placeholder → String?
Placeholder text shown when this component is empty.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → TextInputStyle?
The style of this TextInputComponent.
final
type → MessageComponentType
The type of this component.
no setteroverride
value → String?
The text contained in this component.
final

Methods

defaultToString() → String
Same as toString, but only called when dart:mirrors is not available.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited