ThreadListSyncEvent class

Emitted when the client's thread list is synced.

Inheritance

Properties

channelIds → List<Snowflake>?
The IDs of the channels the threads are syncing for, or null if the entire guild is syncing.
final
channels → List<PartialChannel>?
The channels the threads are syncing for, or null if the entire guild is syncing.
no setter
gateway → Gateway
The gateway that handled this event.
finalinherited
guild → PartialGuild
The guild that the threads are syncing for.
no setter
guildId → Snowflake
The ID of the guild threads are syncing for.
final
hashCode → int
The hash code for this object.
no setterinherited
members → List<ThreadMember>
The members of the synced threads.
final
opcode → Opcode
The opcode of this event.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threads → List<Thread>
The synced threads.
final

Methods

defaultToString() → String
Same as toString, but only called when dart:mirrors is not available.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited