ThreadUpdateBuilder class

Inheritance

Constructors

ThreadUpdateBuilder({String? name, bool? isArchived, Duration? autoArchiveDuration, bool? isLocked, bool? isInvitable, Duration? rateLimitPerUser = sentinelDuration, Flags<ChannelFlags>? flags, List<Snowflake>? appliedTags})

Properties

appliedTags ↔ List<Snowflake>?
getter/setter pair
autoArchiveDuration ↔ Duration?
getter/setter pair
flags ↔ Flags<ChannelFlags>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isArchived ↔ bool?
getter/setter pair
isInvitable ↔ bool?
getter/setter pair
isLocked ↔ bool?
getter/setter pair
name ↔ String?
getter/setter pair
rateLimitPerUser ↔ Duration?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → Map<String, Object?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited