VoiceChannel class abstract

A voice channel.

Implemented types
Implementers

Constructors

VoiceChannel()

Properties

bitrate → int
The bitrate of the channel in bits/s.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → Snowflake
The id of this entity.
finalinherited
json → Map<String, Object?>
finalinherited
manager → ChannelManager
The manager for this entity.
finalinherited
rtcRegion → String?
The ID of the voice region for this channel, or automatic if null.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ChannelType
The type of this channel.
no setterinherited
userLimit → int?
The maximum number of users that can join this channel at once.
no setter
videoQualityMode → VideoQualityMode
The VideoQualityMode for cameras in this channel.
no setter

Methods

defaultToString() → String
Same as toString, but only called when dart:mirrors is not available.
inherited
delete({String? auditLogReason}) → Future<void>
Delete this channel.
inherited
fetch() → Future<Channel>
Fetch this entity from the API.
inherited
follow(Snowflake id) → Future<void>
Follow another channel's announcement messages in this channel.
inherited
get() → Future<Channel>
If this entity exists in the manager's cache, return the cached instance. Otherwise, fetch this entity and return it.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
update(UpdateBuilder<Channel> builder) → Future<Channel>
Update this channel.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited