VoiceState class

A user's voice connection state.

External references:

Properties

cacheKey → Snowflake
The key this voice state will have in the NyxxRest.voice cache.
no setter
channel → PartialChannel?
The channel this voice state is in.
no setter
channelId → Snowflake?
The ID of the channel the user is connected to.
final
guild → PartialGuild?
The guild this voice state is in.
no setter
guildId → Snowflake?
The ID of the guild this state is in.
final
hashCode → int
The hash code for this object.
no setterinherited
isDeafened → bool
Whether this user is deafened.
no setter
isMuted → bool
Whether this user is muted.
no setter
isSelfDeafened → bool
Whether the user has deafened themselves.
final
isSelfMuted → bool
Whether the used has muted themselves.
final
isServerDeafened → bool
Whether the user is deafened by the server.
final
isServerMuted → bool
Whether the user is muted by the server.
final
isStreaming → bool
Whether the user is streaming.
final
isSuppressed → bool
Whether the user is not permitted to speak.
final
isVideoEnabled → bool
Whether the user's camera is enabled.
final
manager → VoiceManager
The manager for this VoiceState.
final
member → Member?
The member this voice state is for.
final
requestedToSpeakAt → DateTime?
The timestamp at which this user requested to speak.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId → String
This state's session ID.
final
user → PartialUser
The user this voice state is for.
no setter
userId → Snowflake
The ID of the user this state is for.
final

Methods

defaultToString() → String
Same as toString, but only called when dart:mirrors is not available.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited